# Estimate Model1 for 1984-1997
#
# Initial version: January 2, 2007
# Revisions: October 18, 2007: normalization of signs to be for
# expansionary shocks.

library(MSBVAR)

# load the data created in the setup file
load("SFB2_models_data.RData")

set.seed(42)

# Find the posterior modes
M1.97 <- szbsvar(Y97, p=p, z=ts(as.matrix(X97)),
                      lambda0=lambda0,
                      lambda1=lambda1,
                      lambda3=lambda3,
                      lambda4=lambda4,
                      lambda5=lambda5,
                      mu5=mu5,
                      mu6=mu6,
                      ident = Model1.A0,
                      qm)

# Sample from the posterior
M1.97.post <- gibbs.A0(M1.97, N1=N1, N2=N2,
                       thin=thin,
                       normalization="DistanceMLA")

# Check convergence in the posterior
M1.97.A0 <- A02mcmc(M1.97.post)
print(geweke.diag(M1.97.A0))
print(summary(M1.97.A0))

# Generate posterior fit, log MDD measures
M1.97.fit <- posterior.fit(M1.97, M1.97.post)
print(M1.97.fit)

# Sample and plot the impulse responses

# Normalize A0s
# Sign pattern we want
ident.sign <- c(1,-1,1,-1,1,1,1,1,1,1,1,1)

# Find the sign pattern in the posterior mode
post.sign <- M1.97.post$ident
post.sign[which(M1.97.post$ident==1)] <-
    sign(apply(A02mcmc(M1.97.post), 2, median))
post.sign <- diag(post.sign)

# Define normalization of posterior mode to the sign pattern we want
# to report
sign.flips <- ifelse(post.sign==ident.sign, 1, -1)

# Compute the IRFs
M1.97.impulses <- mc.irf(M1.97, nsteps=24,
                         A0.posterior=M1.97.post, sign.list=sign.flips)

# IRFs with percentile error bands
pdf(file="M197IRFPercentile.pdf", width=11, height=8)

plot(100*M1.97.impulses, method="Percentile", probs=c(0.16,0.84),
     varnames=colnames(Y97))

mtext("No Accountability, 1985:4-1997:4, 68% percentile bands",
      outer=T, line=5)

dev.off()

# IRFs with SZ likelihood bands
pdf(file="M197IRFSZ2.pdf", width=11, height=8)

plot(100*M1.97.impulses, method="Sims-Zha2",
     component=1,
     probs=c(0.16, 0.84), varnames=colnames(Y97))

mtext("No Accountability, 1985:4-1997:4, 68% likelihood bands",
      outer=T, line=5)

dev.off()


save.image(file="M1-97.RData", compress=T)
q(save="no")
