# Estimate Model4 for 1984-1997
#
# Start Date: January 2007
#
# 20081207 : Updated to do fiscal only

library(MSBVAR)

load("SFB2_models_data.RData")

set.seed(42)

model4.97 <- szbsvar(Y97, p=p, z=as.matrix(X97),
                      lambda0=lambda0,
                      lambda1=lambda1,
                      lambda3=lambda3,
                      lambda4=lambda4,
                      lambda5=lambda5,
                      mu5=mu5,
                      mu6=mu6,
                      ident = Model4.A0,
                      qm)

# Calculate and print model fit

Model4.97.A0.posterior.obj <- gibbs.A0(model4.97, N1=N1, N2=N2,
                                       thin=thin,
                                       normalization="DistanceMLA")

# Check convergence

model4.97.A0 <- A02mcmc(Model4.97.A0.posterior.obj)
print(geweke.diag(model4.97.A0))
print(summary(model4.97.A0))

# Generate some posterior fit measures

model4.97.fit <- posterior.fit(model4.97, Model4.97.A0.posterior.obj)
print(model4.97.fit)

# Sample and plot the impulse responses

Model4.97.impulses <- mc.irf(model4.97, nsteps=24,
                             A0.posterior=Model4.97.A0.posterior.obj)

# IRFs with percentile error bands
pdf(file="Model4.97IRFPercentile.pdf", width=11, height=8)

plot(100*Model4.97.impulses, method="Percentile", probs=c(0.16,0.84),
     varnames=colnames(Y97))

mtext("Accountability, 1985:4-1997:4, 68% percentile bands",
      outer=T, line=5)

dev.off()

# IRFs with SZ likelihood bands
pdf(file="Model4.97IRFSZ2.pdf", width=11, height=8)

plot(100*Model4.97.impulses, method="Sims-Zha2",
     component=1,
     probs=c(0.16, 0.84), varnames=colnames(Y97))

mtext("Accountability, 1985:4-1997:4, 68% likelihood bands",
      outer=T, line=5)

dev.off()


save.image(file="Model4.97.RData", compress=T)
q(save="no")
