# Checks on the A0 matrices and their properties

library(MSBVAR)

# Read in the A0 matrices
load("Model2.97.RData")
rm(Model2.97.impulses)
gc()

load("Model2.06.RData")
rm(Model2.06.impulses)
gc()



"A0.get" <- function(A0,index){
    if(index==1) {st <- 1} else {st <- 1 + (index-1)*length(A0$struct)}
    A0.out <- vector(mode="numeric",length=(A0$m*A0$m))
    A0.out[A0$struct] <- A0$A0[st:(st+length(A0$struct)-1)]
    return(matrix(A0.out,nrow=A0$m))
}


A0inv06.storage <- A0inv97.storage <- matrix(0,
                                             Model2.97.A0.posterior.obj$N2,
                                             sum(Model2.97.A0.posterior.obj$ident))

for(i in 1:Model2.97.A0.posterior.obj$N2)
{

    A0 <- A0.get(Model2.97.A0.posterior.obj$A0.posterior, i)
    A0inv <- solve(A0)
    A0invflat <- A0inv[which(Model2.97.A0.posterior.obj$ident==1)]

    A0inv97.storage[i,] <- A0invflat
    if(i%%1000==1) cat("Processed", i, "\n")

}


for(i in 1:Model2.06.A0.posterior.obj$N2)
{

    A0 <- A0.get(Model2.06.A0.posterior.obj$A0.posterior, i)
    A0inv <- solve(A0)
    A0invflat <- A0inv[which(Model2.06.A0.posterior.obj$ident==1)]

    A0inv06.storage[i,] <- A0invflat
    if(i%%1000==1) cat("Processed", i, "\n")

}


# Compute the median A0
A0inv97.median <- apply(A0inv97.storage, 2, median)
A0inv06.median <- apply(A0inv06.storage, 2, median)

A0inv97.mean <- apply(A0inv97.storage, 2, mean)
A0inv06.mean <- apply(A0inv06.storage, 2, mean)



# Put the median estimates back into the A0 matrix
A0inv97.est <- A0inv06.est <- A0inv97.est1 <- A0inv06.est1 <- matrix(0, m, m)
struct <- Model2.97.A0.posterior.obj$A0.posterior$struct

A0inv97.est[struct] <- A0inv97.median
A0inv06.est[struct] <- A0inv06.median

A0inv97.est1[struct] <- A0inv97.mean
A0inv06.est1[struct] <- A0inv06.mean

# Compare the signs of the equations for the optimized peak A0 versus
# the sampled A0

signs <- cbind(sign(diag(solve(model2.97$A0.mode))),
               sign(diag(A0inv97.est)),
               sign(diag(A0inv97.est1)),
               sign(diag(solve(model2.06$A0.mode))),
               sign(diag(A0inv06.est)),
               sign(diag(A0inv06.est1)))

rownames(signs) <- colnames(Y)
colnames(signs) <- c("Mode 97", "Opt 97 med.", "Opt 97 mn", "Mode 06",
                     "Opt 06 med", "Opt 06 mn")


# Compute DFEVs

dfevs97 <- dfev(model2.97, A0=t(A0inv97.est), k=24)
dfevs06 <- dfev(model2.06, A0=t(A0inv06.est), k=24)


print(dfevs97, latex=T, file="dfevs97.tex")
print(dfevs06, latex=T, file="dfevs06.tex")


# Plots of the dfevs for the models

# DFEVs of macropolity variables for innovations in policy
pdf(file="MacroPdfevs.pdf", width=6, height=8)
par(mfrow=c(4,2), mai=c(0.65,0.65,0.45,0.25), cex=0.75)

for (i in 9:12)
{
    plot(ts(dfevs97$errors[,2,i]), ylim=c(0,100),
         ylab=dfevs97$names[i], xlab="Months")
    lines(ts(dfevs06$errors[,2,i]), lty=2)

    if(i==9) {mtext("IR", line=1)}

    plot(ts(dfevs97$errors[,4,i]), ylim=c(0,100),
         ylab=dfevs97$names[i], xlab="Months")
    lines(ts(dfevs06$errors[,4,i]), lty=2)

    if(i==9) {mtext("G", line=1)}
}

dev.off()


# DFEVs of policy variables for innovations in macropolity
IR.dfev97 <- dfevs97$errors[,,2]
G.dfev97 <- dfevs97$errors[,,4]

IR.dfev06 <- dfevs06$errors[,,2]
G.dfev06 <- dfevs06$errors[,,4]

pdf(file="Policydfevs.pdf", width=8, height=6)
par(mfcol=c(2,4), mai=c(0.65,0.65,0.45,0.25), cex=0.75)

i <- 1
for(j in 9:12)
{
    plot(ts(IR.dfev97[,j]), ylim=c(0,100),
         ylab="", xlab="Months")
    lines(ts(IR.dfev06[,j]), lty=2)

        i <- i+1

    if(j==9) {mtext("IR", line=2, side=2)}
    if(j==9 & i==2) mtext(dfevs97$names[j], side=3, line=1)
    if(j==10 & i==3) mtext(dfevs97$names[j], side=3, line=1)
    if(j==11 & i==4) mtext(dfevs97$names[j], side=3, line=1)
    if(j==12 & i==5) mtext(dfevs97$names[j], side=3, line=1)

    plot(ts(G.dfev97[,j]), ylim=c(0,100),
         ylab="", xlab="Months")
    lines(ts(G.dfev06[,j]), lty=2)

    if(j==9) {mtext("G", line=2, side=2)}

}
dev.off()
