# SpecificationlogMDD.R
#
# Fits a series of idenitification schemes for each subsample.  Used
# to generate the log MDD valuesfor the table in the paper.
#
# Patrick T. Brandt
#
# 20080124 : Initial version
#
#

library(MSBVAR)


# Read in the data
# ----------------
#
# Complete dataset

SFB <- read.csv("UK20070103.csv",sep = ",", header=TRUE)

# Get the observations we want from the 1979-2006 data
Y.tmp <- window(ts(SFB, start=c(1979, 1), freq=12), start=c(1984, 4), end=c(2006,9))

rm(SFB)
attach(as.data.frame(Y.tmp))

## # Now standardize the net cash as period over period % changes
## #

## netcash <- Y.tmp[,"netcash"]
## netcash <- diff(netcash, lag=12)/lag(netcash, lag=12)
## #diff(Y.tmp[,"netcash"], lag=12)/Y.tmp[,"netcash"]

Y <- ts(cbind(log(Y.tmp[,"usxr"]), 0.01*Y.tmp[,"ir"], 0.01*Y.tmp[,"usir"],
              log(Y.tmp[,"debtindex"]), log(Y.tmp[,"cpi"]),
              log(Y.tmp[,"iip"]), log(Y.tmp[,"uscpi"]),
              log(Y.tmp[,"usiip"]), 0.01*Y.tmp[,"nexp"],
              0.01*Y.tmp[,"pexp"], 0.01*Y.tmp[,"pm"], 0.01*Y.tmp[,"vi"]),
              start=c(1984,4), frequency=12,
              names = c("XR", "IR", "USIR", "G", "CPI", "IIP",
              "USCPI", "USIIP", "SE",
              "PE", "PM", "VI"))

Y <- window(Y, start=c(1984,4))

# Single election counter
X <- ts(Y.tmp[, "counter"], start=c(1984,4), frequency=12,
        names = c("ELECTION"))

# Separate election counters
X1 <- ts(Y.tmp[, c("counter1", "counter2", "counter3", "counter4",
                   "counter5", "counter6")], start=c(1984,4),
               frequency=12,
        names = paste("ELECTION", 1:6, sep=""))

################################################################
# Now generate the sub-samples using the window() function
#
# Subsample 1984:4 - 1997:4

Y97 <- window(Y, end=c(1997,4))

X97 <- window(X, end=c(1997,4))

X197 <- window(X1[,1:3], end=c(1997,4))

# Subsample 1997:5 - 2006:9

Y06 <- window(Y, start=c(1997,5), end=c(2006,9))

X06 <- window(X, start=c(1997,5), end=c(2006,9))

X106 <- window(X1[,4:6], start=c(1997,5), end=c(2006,9))


# Define A0s
# ----------
#
# No Fiscal, but Monetary Accountability Model

m <- ncol(Y)
MonetaryOnly.A0 <- matrix(0,m,m)
diag(MonetaryOnly.A0) <- 1
colnames(MonetaryOnly.A0) <- c("XR", "IR", "USIR", "G", "CPI", "IIP", "USCPI", "USIIP", "SE",
                        "PE", "PM", "VI")
rownames(MonetaryOnly.A0) <- colnames(MonetaryOnly.A0)

MonetaryOnly.A0[2:12,1] <- 1
MonetaryOnly.A0[1:4,2] <- 1
MonetaryOnly.A0[9:12,2] <- 1
MonetaryOnly.A0[1,3] <- 1
MonetaryOnly.A0[1:2,4] <- 1
MonetaryOnly.A0[6:8,5] <- 1
MonetaryOnly.A0[7:8,6] <- 1
MonetaryOnly.A0[8,7] <- 1
MonetaryOnly.A0[2,9:12] <- 1
MonetaryOnly.A0[9,10] <- 1
MonetaryOnly.A0[9:10,11] <- 1
MonetaryOnly.A0[9:11,12] <- 1

# Fiscal, but no Monetary Accountability Model
FiscalOnly.A0 <- matrix(0,m,m)
diag(FiscalOnly.A0) <- 1
colnames(FiscalOnly.A0) <- c("XR", "IR", "USIR", "G", "CPI", "IIP", "USCPI", "USIIP", "SE",
                        "PE", "PM", "VI")
rownames(FiscalOnly.A0) <- colnames(FiscalOnly.A0)

FiscalOnly.A0[2:12,1] <- 1
FiscalOnly.A0[1:4,2] <- 1
FiscalOnly.A0[1,3] <- 1
FiscalOnly.A0[1:2,4] <- 1
FiscalOnly.A0[6:8,5] <- 1
FiscalOnly.A0[7:8,6] <- 1
FiscalOnly.A0[8,7] <- 1
FiscalOnly.A0[9,10] <- 1
FiscalOnly.A0[9:10,11] <- 1
FiscalOnly.A0[9:11,12] <- 1
FiscalOnly.A0[4,9:12] <- 1
FiscalOnly.A0[9:12,4] <- 1

# Full Accountability Model

MonetaryandFiscal.A0 <- matrix(0,m,m)
diag(MonetaryandFiscal.A0) <- 1
colnames(MonetaryandFiscal.A0) <- c("XR", "IR", "USIR", "G", "CPI", "IIP", "USCPI", "USIIP", "SE",
                        "PE", "PM", "VI")
rownames(MonetaryandFiscal.A0) <- colnames(MonetaryandFiscal.A0)

MonetaryandFiscal.A0[2:12,1] <- 1
MonetaryandFiscal.A0[1:4,2] <- 1
MonetaryandFiscal.A0[9:12,2] <- 1
MonetaryandFiscal.A0[1,3] <- 1
MonetaryandFiscal.A0[1:2,4] <- 1
MonetaryandFiscal.A0[9:12,4] <- 1
MonetaryandFiscal.A0[6:8,5] <- 1
MonetaryandFiscal.A0[7:8,6] <- 1
MonetaryandFiscal.A0[8,7] <- 1
MonetaryandFiscal.A0[2,9:12] <- 1
MonetaryandFiscal.A0[4,9:12] <- 1
MonetaryandFiscal.A0[9,10] <- 1
MonetaryandFiscal.A0[9:10,11] <- 1
MonetaryandFiscal.A0[9:11,12] <- 1


# No fiscal or monetary accountability Model

NoAcct.A0 <- matrix(0,m,m)
diag(NoAcct.A0) <- 1
colnames(NoAcct.A0) <- c("XR", "IR", "USIR", "G", "CPI", "IIP", "USCPI", "USIIP", "SE",
                        "PE", "PM", "VI")
rownames(NoAcct.A0) <- colnames(NoAcct.A0)

NoAcct.A0[2:12,1] <- 1
NoAcct.A0[1:4,2] <- 1
NoAcct.A0[1,3] <- 1
NoAcct.A0[1:2,4] <- 1
NoAcct.A0[6:8,5] <- 1
NoAcct.A0[7:8,6] <- 1
NoAcct.A0[8,7] <- 1
NoAcct.A0[9,10] <- 1
NoAcct.A0[9:10,11] <- 1
NoAcct.A0[9:11,12] <- 1


# Set parameters / hyperparameters for the models

p <- 6
qm <- 12
N1 <- 10000
N2 <- 25000
thin <- 1

lambda0 <- 0.6
lambda1 <- 0.1
lambda3 <- 1
lambda4 <- 0.1
lambda5 <- 0.05
mu5 <- 5
mu6 <- 5


A0.list <- list(NoAcct.A0, MonetaryOnly.A0, FiscalOnly.A0,
                MonetaryandFiscal.A0)


# Now loop over the models and the sample periods to estimate the
# models and their log MDDs

Results <- matrix(0, 4, 6)
colnames(Results) <- c("Tory Period, One Counter",
                       "Labour Period, One Counter",
                       "Tory Period, Separate Counters",
                       "Labour Period, Separate Counters",
                       "Tory Period, No Counters", "Labour Period, No Counters")

rownames(Results) <- c("No Accountability", "Monetary Accountability",
                       "Fiscal Accountability", "Monetary and Fiscal Accountability")

for(i in 1:length(A0.list))

{

    # Find posterior modes

    # Models with one election counter
    M97 <- szbsvar(Y97, p=p, z=ts(as.matrix(X97)),
                   lambda0=lambda0,
                   lambda1=lambda1,
                   lambda3=lambda3,
                   lambda4=lambda4,
                   lambda5=lambda5,
                   mu5=mu5,
                   mu6=mu6,
                   ident = A0.list[[i]],
                   qm)

    M06 <- szbsvar(Y06, p=p, z=ts(as.matrix(X06)),
                   lambda0=lambda0,
                   lambda1=lambda1,
                   lambda3=lambda3,
                   lambda4=lambda4,
                   lambda5=lambda5,
                   mu5=mu5,
                   mu6=mu6,
                   ident = A0.list[[i]],
                   qm)

    # Models with separate counters for each election
    M97.6 <- szbsvar(Y97, p=p, z=ts(as.matrix(X197)),
                   lambda0=lambda0,
                   lambda1=lambda1,
                   lambda3=lambda3,
                   lambda4=lambda4,
                   lambda5=lambda5,
                   mu5=mu5,
                   mu6=mu6,
                   ident = A0.list[[i]],
                   qm)

    M06.6 <- szbsvar(Y06, p=p, z=ts(as.matrix(X106)),
                   lambda0=lambda0,
                   lambda1=lambda1,
                   lambda3=lambda3,
                   lambda4=lambda4,
                   lambda5=lambda5,
                   mu5=mu5,
                   mu6=mu6,
                   ident = A0.list[[i]],
                   qm)

    # Models with no counters

    M97.no <- szbsvar(Y97, p=p, z=NULL,
                   lambda0=lambda0,
                   lambda1=lambda1,
                   lambda3=lambda3,
                   lambda4=lambda4,
                   lambda5=lambda5,
                   mu5=mu5,
                   mu6=mu6,
                   ident = A0.list[[i]],
                   qm)

    M06.no <- szbsvar(Y06, p=p, z=NULL,
                   lambda0=lambda0,
                   lambda1=lambda1,
                   lambda3=lambda3,
                   lambda4=lambda4,
                   lambda5=lambda5,
                   mu5=mu5,
                   mu6=mu6,
                   ident = A0.list[[i]],
                   qm)


    # Sample from posterior and compute log MDD
    M97.sample <- gibbs.A0(M97, N1=N1, N2=N2, thin=thin,
                           normalization="DistanceMLA")

    fit97 <- posterior.fit(M97, M97.sample)

    rm(M97.sample); gc()

    M06.sample <- gibbs.A0(M06, N1=N1, N2=N2, thin=thin,
                           normalization="DistanceMLA")

    fit06 <- posterior.fit(M06, M06.sample)

    rm(M06.sample); gc()

    # Models with 6 counters
    M97.sample <- gibbs.A0(M97.6, N1=N1, N2=N2, thin=thin,
                           normalization="DistanceMLA")

    fit976 <- posterior.fit(M97, M97.sample)

    rm(M97.sample); gc()

    M06.sample <- gibbs.A0(M06.6, N1=N1, N2=N2, thin=thin,
                           normalization="DistanceMLA")

    fit066 <- posterior.fit(M06, M06.sample)

    rm(M06.sample); gc()

    # Models with no counters
    M97.sample <- gibbs.A0(M97.no, N1=N1, N2=N2, thin=thin,
                           normalization="DistanceMLA")

    fit97no <- posterior.fit(M97, M97.sample)

    rm(M97.sample); gc()

    M06.sample <- gibbs.A0(M06.no, N1=N1, N2=N2, thin=thin,
                           normalization="DistanceMLA")

    fit06no <- posterior.fit(M06, M06.sample)

    rm(M06.sample); gc()

    # Save the Results
    Results[i, 1] <- fit97$log.marginal.data.density
    Results[i, 2] <- fit06$log.marginal.data.density

    Results[i, 3] <- fit976$log.marginal.data.density
    Results[i, 4] <- fit066$log.marginal.data.density

    Results[i, 5] <- fit97no$log.marginal.data.density
    Results[i, 6] <- fit06no$log.marginal.data.density

}

# Print the final table of results
print(xtable(Results, digits=0), type="html", file="logMDD.html")


q(save="no")



