# Estimate Model2 for 1997-2006
#
# Start Date: January 2007
#
# This version: January 2, 2007

library(MSBVAR)

load("SFB2_models_data.RData")

set.seed(42)

model2.06 <- szbsvar(Y, p=p, z=as.matrix(X),
                      lambda0=lambda0,
                      lambda1=lambda1,
                      lambda3=lambda3,
                      lambda4=lambda4,
                      lambda5=lambda5,
                      mu5=mu5,
                      mu6=mu6,
                      ident = Model2.A0,
                      qm)

# Calculate and print model fit

Model2.06.A0.posterior.obj <- gibbs.A0(model2.06, N1=N1, N2=N2,
                                       thin=thin,
                                       normalization="DistanceMLA")

# Check convergence

model2.06.A0 <- A02mcmc(Model2.06.A0.posterior.obj)
print(geweke.diag(model2.06.A0))
print(summary(model2.06.A0))

# Generate some posterior fit measures

model2.06.fit <- posterior.fit(model2.06, Model2.06.A0.posterior.obj)
print(model2.06.fit)

# Sample and plot the impulse responses

Model2.06.impulses <- mc.irf(model2.06, nsteps=24,
                             A0.posterior=Model2.06.A0.posterior.obj)

# IRFs with percentile error bands
pdf(file="Model2.06IRFPercentile.pdf", width=11, height=8)

plot(100*Model2.06.impulses, method="Percentile",
     varnames=colnames(Y))

mtext("Accountability, 1997:5-2006:9, 68% percentile bands",
      outer=T, line=5)

dev.off()

# IRFs with SZ likelihood bands
pdf(file="Model2.06IRFSZ2.pdf", width=11, height=8)

plot(100*Model2.06.impulses, varnames=colnames(Y))

mtext("Accountability, 1997:5-2006:9, 68% likelihood bands",
      outer=T, line=5)

dev.off()


save.image(file="Model2.06.RData", compress=T)
q(save="no")
