# DFEVs for the Accountability Models
#
# Patrick T. Brandt
# pbrandt@utdallas.edu
#
#

library(MSBVAR)

load("SFB2_models_data.RData")

# Accountability Model for 1984-1997
set.seed(42)

model2.97 <- szbsvar(Y97, p=p, z=as.matrix(X97),
                      lambda0=lambda0,
                      lambda1=lambda1,
                      lambda3=lambda3,
                      lambda4=lambda4,
                      lambda5=lambda5,
                      mu5=mu5,
                      mu6=mu6,
                      ident = Model2.A0,
                      qm)


# Accountability Model for 1997-2006

set.seed(42)

model2.06 <- szbsvar(Y06, p=p, z=as.matrix(X06),
                      lambda0=lambda0,
                      lambda1=lambda1,
                      lambda3=lambda3,
                      lambda4=lambda4,
                      lambda5=lambda5,
                      mu5=mu5,
                      mu6=mu6,
                      ident = Model2.A0,
                      qm)


# Compute the DFEVs for each equation.
dfevs97 <- dfev(model2.97, A0=t(solve(model2.97$A0.mode)), k=24)
dfevs06 <- dfev(model2.06, A0=t(solve(model2.06$A0.mode)), k=24)

print(dfevs97, latex=T, file="dfevs97.tex")
print(dfevs06, latex=T, file="dfevs06.tex")
