# setupSFB2.R
#
# Setup file for running Sattler-Freeman-Brandt Open economy /
# politics models
#
# Thomas Sattler and Patrick T. Brandt
# 20060102 : Initial version
# 20070130 : Includes new model with NO fiscal or monetary
#            accountability using the netcash measure.
# 20070212 : Version without SE and PE equations to test robustness.
# 20070214 : Added exog dummy for Tory / Labour regime

# Read in the data
# ----------------
#
# Complete dataset

SFB <- read.csv("UK20070103.csv",sep = ",", header=TRUE)

# Get the observations we want from the 1979-2006 data
Y.tmp <- window(ts(SFB, start=c(1979, 1), freq=12), start=c(1984, 4), end=c(2006,9))

rm(SFB)
attach(as.data.frame(Y.tmp))

Y <- ts(cbind(log(Y.tmp[,"usxr"]), 0.01*Y.tmp[,"ir"], 0.01*Y.tmp[,"usir"],
              log(Y.tmp[,"debtindex"]), log(Y.tmp[,"cpi"]),
              log(Y.tmp[,"iip"]), log(Y.tmp[,"uscpi"]),
              log(Y.tmp[,"usiip"]), 0.01*Y.tmp[,"pm"], 0.01*Y.tmp[,"vi"]),
              start=c(1984,4), frequency=12,
              names = c("XR", "IR", "USIR", "G", "CPI", "IIP",
              "USCPI", "USIIP", "PM", "VI"))

Y <- window(Y, start=c(1984,4))

TLregime <- ts(c(rep(1,157), rep(0,113)), start=c(1984,4), freq=12)


X <- ts(Y.tmp[, "counter"], start=c(1984,4), frequency=12,
        names = c("ELECTION"))

X <- cbind(X, TLregime)

# Define A0s
# ----------
#
# No Fiscal, but Monetary Accountability Model

m <- ncol(Y)
Model1.A0 <- matrix(0,m,m)
diag(Model1.A0) <- 1
colnames(Model1.A0) <- c("XR", "IR", "USIR", "G", "CPI", "IIP", "USCPI", "USIIP", "PM", "VI")
rownames(Model1.A0) <- colnames(Model1.A0)

Model1.A0[2:m,1] <- 1
Model1.A0[1:4,2] <- 1
Model1.A0[9:m,2] <- 1
Model1.A0[1,3] <- 1
Model1.A0[1:2,4] <- 1
Model1.A0[6:8,5] <- 1
Model1.A0[7:8,6] <- 1
Model1.A0[8,7] <- 1
Model1.A0[2,9:m] <- 1
Model1.A0[9,10] <- 1


# Accountability Model

Model2.A0 <- matrix(0,m,m)
diag(Model2.A0) <- 1
colnames(Model2.A0) <- c("XR", "IR", "USIR", "G", "CPI", "IIP", "USCPI", "USIIP", "PM", "VI")
rownames(Model2.A0) <- colnames(Model2.A0)

Model2.A0[2:m,1] <- 1
Model2.A0[1:4,2] <- 1
Model2.A0[9:m,2] <- 1
Model2.A0[1,3] <- 1
Model2.A0[1:2,4] <- 1
Model2.A0[9:m,4] <- 1
Model2.A0[6:8,5] <- 1
Model2.A0[7:8,6] <- 1
Model2.A0[8,7] <- 1
Model2.A0[2,9:m] <- 1
Model2.A0[4,9:m] <- 1
Model2.A0[9,10] <- 1



# No fiscal or monetary accountability Model

Model3.A0 <- matrix(0,m,m)
diag(Model3.A0) <- 1
colnames(Model3.A0) <- c("XR", "IR", "USIR", "G", "CPI", "IIP", "USCPI", "USIIP", "PM", "VI")
rownames(Model3.A0) <- colnames(Model3.A0)

Model3.A0[2:m,1] <- 1
Model3.A0[1:4,2] <- 1
Model3.A0[1,3] <- 1
Model3.A0[1:2,4] <- 1
Model3.A0[6:8,5] <- 1
Model3.A0[7:8,6] <- 1
Model3.A0[8,7] <- 1
Model3.A0[9,10] <- 1


# Set parameters / hyperparameters for the models

p <- 12
qm <- 12
N1 <- 10000
N2 <- 30000
thin <- 1

lambda0 <- 0.6
lambda1 <- 0.1
lambda3 <- 1
lambda4 <- 0.1
lambda5 <- 0.05
mu5 <- 5
mu6 <- 5

save.image("SFB2_models_data.RData")

q(save="no")

