# Estimate Model1 for 1984-1997
#
# Start Date: January 2007
#
# This version: January 2, 2007

library(MSBVAR)

load("SFB2_models_data.RData")

set.seed(42)

model1.97 <- szbsvar(Y97, p=p, z=as.matrix(X97),
                      lambda0=lambda0,
                      lambda1=lambda1,
                      lambda3=lambda3,
                      lambda4=lambda4,
                      lambda5=lambda5,
                      mu5=mu5,
                      mu6=mu6,
                      ident = Model1.A0,
                      qm)

# Sample

Model1.97.A0.posterior.obj <- gibbs.A0(model1.97, N1=N1, N2=N2,
                                       thin=thin,
                                       normalization="DistanceMLA")

# Check convergence

model1.97.A0 <- A02mcmc(Model1.97.A0.posterior.obj)
print(geweke.diag(model1.97.A0))
print(summary(model1.97.A0))

# Generate some posterior fit measures

model1.97.fit <- posterior.fit(model1.97, Model1.97.A0.posterior.obj)
print(model1.97.fit)

# Sample and plot the impulse responses

Model1.97.impulses <- mc.irf(model1.97, nsteps=24,
                             A0.posterior=Model1.97.A0.posterior.obj)

# IRFs with percentile error bands
pdf(file="Model1.97IRFPercentile.pdf", width=11, height=8)

plot(100*Model1.97.impulses, method="Percentile",
     varnames=colnames(Y97))

mtext("No Accountability, 1985:4-1997:4, 68% percentile bands",
      outer=T, line=5)

dev.off()

# IRFs with SZ likelihood bands
pdf(file="Model1.97IRFSZ2.pdf", width=11, height=8)

plot(100*Model1.97.impulses, varnames=colnames(Y97))

mtext("No Accountability, 1985:4-1997:4, 68% likelihood bands",
      outer=T, line=5)

dev.off()


save.image(file="Model1.97.RData", compress=T)
q(save="no")
