# Estimate Model3 for 1997-2006
#
# Start Date: January 2007
#
# This version: 20070130

library(MSBVAR)

load("SFB2_models_data.RData")

set.seed(42)

model3.06 <- szbsvar(Y06, p=p, z=as.matrix(X06),
                      lambda0=lambda0,
                      lambda1=lambda1,
                      lambda3=lambda3,
                      lambda4=lambda4,
                      lambda5=lambda5,
                      mu5=mu5,
                      mu6=mu6,
                      ident = Model3.A0,
                      qm)

# Calculate and print model fit

Model3.06.A0.posterior.obj <- gibbs.A0(model3.06, N1=N1, N2=N2,
                                       thin=thin,
                                       normalization="DistanceMLA")

# Check convergence

model3.06.A0 <- A02mcmc(Model3.06.A0.posterior.obj)
print(geweke.diag(model3.06.A0))
print(summary(model3.06.A0))

# Generate some posterior fit measures

model3.06.fit <- posterior.fit(model3.06, Model3.06.A0.posterior.obj)
print(model3.06.fit)

# Sample and plot the impulse responses

Model3.06.impulses <- mc.irf(model3.06, nsteps=24,
                             A0.posterior=Model3.06.A0.posterior.obj)

# IRFs with percentile error bands
pdf(file="Model3.06IRFPercentile.pdf", width=11, height=8)

plot(100*Model3.06.impulses, method="Percentile",
     varnames=colnames(Y06))

mtext("Accountability, 1997:5-2006:9, 68% percentile bands",
      outer=T, line=5)

dev.off()

# IRFs with SZ likelihood bands
pdf(file="Model3.06IRFSZ2.pdf", width=11, height=8)

plot(100*Model3.06.impulses, varnames=colnames(Y06))

mtext("Accountability, 1997:5-2006:9, 68% likelihood bands",
      outer=T, line=5)

dev.off()


save.image(file="Model3.06.RData", compress=T)
q(save="no")
