# setupSFB2.R
#
# Setup file for running Sattler-Freeman-Brandt Open economy /
# politics models
#
# Thomas Sattler and Patrick T. Brandt
# 20060102 : Initial version
# 20070130 : Includes new model with NO fiscal or monetary
#            accountability using the netcash measure.



# Read in the data
# ----------------
#
# Complete dataset

SFB <- read.csv("UK.csv",sep = ",", header=TRUE)

# Get the observations we want from the 1979-2006 data
Y.tmp <- ts(SFB, start=c(1984, 4), freq=12)

rm(SFB)
attach(as.data.frame(Y.tmp))

Y <- ts(cbind(log(Y.tmp[,"usxr"]), 0.01*Y.tmp[,"ir"], 0.01*Y.tmp[,"usir"],
              log(Y.tmp[,"rd"]), log(Y.tmp[,"cpi"]),
              log(Y.tmp[,"iip"]), log(Y.tmp[,"uscpi"]),
              log(Y.tmp[,"usiip"]), 0.01*Y.tmp[,"nexp"],
              0.01*Y.tmp[,"pexp"], 0.01*Y.tmp[,"pm"], 0.01*Y.tmp[,"vi"]),
              start=c(1984,4), frequency=12,
              names = c("XR", "IR", "USIR", "G", "CPI", "IIP",
              "USCPI", "USIIP", "SE",
              "PE", "PM", "VI"))

Y <- window(Y, start=c(1984,4))

X <- ts(Y.tmp[, "counter"], start=c(1984,4), frequency=12,
        names = c("ELECTION"))


################################################################
# Now generate the sub-samples using the window() function
#
# Subsample 1984:4 - 1997:4

Y97 <- window(Y, end=c(1997,4))

X97 <- window(X, end=c(1997,4))

# Subsample 1997:5 - 2006:9

Y06 <- window(Y, start=c(1997,5), end=c(2006,9))

X06 <- window(X, start=c(1997,5), end=c(2006,9))


# Define A0s
# ----------
#
# No Fiscal, but Monetary Accountability Model

m <- ncol(Y)
Model1.A0 <- matrix(0,m,m)
diag(Model1.A0) <- 1
colnames(Model1.A0) <- c("XR", "IR", "USIR", "G", "CPI", "IIP", "USCPI", "USIIP", "SE",
                        "PE", "PM", "VI")
rownames(Model1.A0) <- colnames(Model1.A0)

Model1.A0[2:12,1] <- 1
Model1.A0[1:4,2] <- 1
Model1.A0[9:12,2] <- 1
Model1.A0[1,3] <- 1
Model1.A0[1:2,4] <- 1
Model1.A0[6:8,5] <- 1
Model1.A0[7:8,6] <- 1
Model1.A0[8,7] <- 1
Model1.A0[2,9:12] <- 1
Model1.A0[9,10] <- 1
Model1.A0[9:10,11] <- 1
Model1.A0[9:11,12] <- 1


# Accountability Model

Model2.A0 <- matrix(0,m,m)
diag(Model2.A0) <- 1
colnames(Model2.A0) <- c("XR", "IR", "USIR", "G", "CPI", "IIP", "USCPI", "USIIP", "SE",
                        "PE", "PM", "VI")
rownames(Model2.A0) <- colnames(Model2.A0)

Model2.A0[2:12,1] <- 1
Model2.A0[1:4,2] <- 1
Model2.A0[9:12,2] <- 1
Model2.A0[1,3] <- 1
Model2.A0[1:2,4] <- 1
Model2.A0[9:12,4] <- 1
Model2.A0[6:8,5] <- 1
Model2.A0[7:8,6] <- 1
Model2.A0[8,7] <- 1
Model2.A0[2,9:12] <- 1
Model2.A0[4,9:12] <- 1
Model2.A0[9,10] <- 1
Model2.A0[9:10,11] <- 1
Model2.A0[9:11,12] <- 1


# No fiscal or monetary accountability Model

Model3.A0 <- matrix(0,m,m)
diag(Model3.A0) <- 1
colnames(Model3.A0) <- c("XR", "IR", "USIR", "G", "CPI", "IIP", "USCPI", "USIIP", "SE",
                        "PE", "PM", "VI")
rownames(Model3.A0) <- colnames(Model3.A0)

Model3.A0[2:12,1] <- 1
Model3.A0[1:4,2] <- 1
#Model3.A0[9:12,2] <- 1
Model3.A0[1,3] <- 1
Model3.A0[1:2,4] <- 1
#Model3.A0[9:12,4] <- 1
Model3.A0[6:8,5] <- 1
Model3.A0[7:8,6] <- 1
Model3.A0[8,7] <- 1
#Model3.A0[2,9:12] <- 1
#Model3.A0[4,9:12] <- 1
Model3.A0[9,10] <- 1
Model3.A0[9:10,11] <- 1
Model3.A0[9:11,12] <- 1




# Set parameters / hyperparameters for the models

p <- 6
qm <- 12
N1 <- 5000
N2 <- 20000
thin <- 1

lambda0 <- 0.6
lambda1 <- 0.1
lambda3 <- 1
lambda4 <- 0.1
lambda5 <- 0.05
mu5 <- 5
mu6 <- 5

save.image("SFB2_models_data.RData")

q(save="no")







